@@ -98,8 +98,11 @@ class Check:
                                              getattr(self._check_java_class, 'apply$default$3')()
                                              )
         self.constraints = constraints if constraints else []
-        for constraint in self.constraints:
-            self.addConstraint(constraint)
+
+    def addConstraints(self, constraints: list):
+        self.constraints.extend(constraints)
+        for constraint in constraints:
+            self._Check = constraint._Check
 
     def addConstraint(self, constraint):
         """
@@ -107,7 +110,8 @@ class Check:
         :param Constraint constraint: new constraint to be added.
         :return: new Check object
         """
-        raise NotImplementedError("Private factory method for other check methods")
+        self.constraints.append(constraint)
+        self._Check = constraint._Check
 
     def addFilterableContstraint(self, creationFunc):
         """ Adds a constraint that can subsequently be replaced with a filtered version
